| predict.dindexfit | R Documentation |
Prediction based on distributional index model fit.
## S3 method for class 'dindexfit'
predict(
object,
data = NULL,
digits = NULL,
interpolation = NULL,
asplitAvail = NULL,
...
)
object |
DIM fit (object of class |
data |
optional |
digits |
number of decimal places for the predictive CDF. Accepted for backwards compatibility but currently ignored (a warning is issued once per session); predictions are returned at full precision. |
interpolation |
interpolation method for univariate index, ignored at this time. Only linear is supported for a univariate index, multivariate uses midpoint. |
asplitAvail |
kept for backwards compatibility, ignored. |
... |
further arguments passed to the index prediction function. |
A list of predictions, as for predict.idrfit.
Examples in dindexm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.