survival_isotonic_distributional_regression_threshold: Compute an isotonic regression of a probability given by...

View source: R/extendr-wrappers.R

survival_isotonic_distributional_regression_thresholdR Documentation

Compute an isotonic regression of a probability given by Kaplan-Meier estimators (= one threshold of S-IDR).

Description

This method is provided for completeness and to make the S-IDR publication easier to reproduce.

Usage

survival_isotonic_distributional_regression_threshold(
  threshold,
  X,
  y,
  y_observed,
  weights,
  decreasing = FALSE
)

Arguments

threshold

Double of the response value at which to compute the IDR solution.

X

Double vector of totally ordered covariates.

y

Double vector of response values.

y_observed

Integer vector: 1 for observed, 0 for censored.

weights

Double vector of non-negative weights. All vectors must have equal length.

decreasing

Bool indicating direction (decreasing is a CIDR threshold).

Value

Numeric vector. The i'th entry gives the fitted CDF at covariate i.

Examples

survival_isotonic_distributional_regression_threshold(3.5, as.double(1:4), c(2, 1, 4, 3),
  as.integer(c(1, 0, 0, 0)), rep(1.0, 4))

isodistrreg documentation built on Aug. 21, 2026, 5:16 p.m.