plain_survival_isotonic_distributional_regression: Compute the plain survival IDR for totally ordered co-variates under the hazard rate order
assumption for censored data. Note that the hazard rate order is needed for the method to be
consistent, but that the returned solution likely doesn't satisfy this assumption.
Description
Computes the plain survival isotonic distributional regression (plain survival IDR) under the
hazard rate order assumption for totally ordered covariates when some responses are right
censored. Returns the fitted cumulative distribution evaluated at each response threshold for
each unique covariate.
Usage
plain_survival_isotonic_distributional_regression(X, y, y_observed, weights)
Value
Numeric matrix. The (i, j) entry gives the fitted CDF at (unique) response j for
(unique) covariate i.
Arguments
X
Double vector of scalar covariates.
y
Double vector of response values.
y_observed
Integer vector: 1 for observed, 0 for censored.
weights
Double vector of non-negative weights. All vectors must have equal length.
Details
This method is provided for completeness and to make the S-IDR publication easier to reproduce,
but is not recommended for use by practitioners due to prohibitive computational costs and
potential inconsistency in case the distributions are not hazard rate ordered.