plain_survival_isotonic_distributional_regression_threshold: Compute an isotonic regression of a probability given by Kaplan-Meier estimators (= one
threshold of the plain survival IDR data). Note that this is the non-recursive
version that is consistent only under the hazard rate order assumption.
Description
Computes a single threshold of the plain survival isotonic distributional regression (plain
survival IDR) under the hazard rate order assumption for totally ordered covariates when some
responses are right-censored. Returns the fitted cumulative distribution evaluated at the
threshold for each unique covariate.