Learn R Programming

isodistrreg (version 0.6.0)

predict.dindexfit: Predict method for distributional index model (DIM)

Description

Prediction based on distributional index model fit.

Usage

# S3 method for dindexfit
predict(
  object,
  data = NULL,
  digits = NULL,
  interpolation = NULL,
  asplitAvail = NULL,
  ...
)

Value

A list of predictions, as for predict.idrfit.

Arguments

object

DIM fit (object of class "dindexfit").

data

optional data.frame containing variables with which to predict. In-sample predictions are returned if this is omitted.

digits

number of decimal places for the predictive CDF. Accepted for backwards compatibility but currently ignored (a warning is issued once per session); predictions are returned at full precision.

interpolation

interpolation method for univariate index, ignored at this time. Only linear is supported for a univariate index, multivariate uses midpoint.

asplitAvail

kept for backwards compatibility, ignored.

...

further arguments passed to the index prediction function.

See Also

Examples in dindexm.