Prediction based on distributional index model fit.
# S3 method for dindexfit
predict(
object,
data = NULL,
digits = NULL,
interpolation = NULL,
asplitAvail = NULL,
...
)A list of predictions, as for predict.idrfit.
DIM fit (object of class "dindexfit").
optional data.frame containing variables with which to
predict. In-sample predictions are returned if this is omitted.
number of decimal places for the predictive CDF. Accepted for backwards compatibility but currently ignored (a warning is issued once per session); predictions are returned at full precision.
interpolation method for univariate index, ignored at this time. Only linear is supported for a univariate index, multivariate uses midpoint.
kept for backwards compatibility, ignored.
further arguments passed to the index prediction function.
Examples in dindexm.