View source: R/extendr-wrappers.R
| survival_isotonic_distributional_regression_threshold | R Documentation |
This method is provided for completeness and to make the S-IDR publication easier to reproduce.
survival_isotonic_distributional_regression_threshold(
threshold,
X,
y,
y_observed,
weights,
decreasing = FALSE
)
threshold |
Double of the response value at which to compute the IDR solution. |
X |
Double vector of totally ordered covariates. |
y |
Double vector of response values. |
y_observed |
Integer vector: 1 for observed, 0 for censored. |
weights |
Double vector of non-negative weights. All vectors must have equal length. |
decreasing |
Bool indicating direction (decreasing is a CIDR threshold). |
Numeric vector. The i'th entry gives the fitted CDF at covariate i.
survival_isotonic_distributional_regression_threshold(3.5, as.double(1:4), c(2, 1, 4, 3),
as.integer(c(1, 0, 0, 0)), rep(1.0, 4))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.